@@ -11,9 +11,12 @@ class PageContent(SemanthaModelEntity):
 
     @property
     def paragraphs(self) -> list[Paragraph]:
-        return [
-            Paragraph(raw_paragraph) for raw_paragraph in self.data["paragraphs"]
-        ]
+        if "paragraphs" in self.data:
+            return [
+                Paragraph(raw_paragraph) for raw_paragraph in self.data["paragraphs"]
+            ]
+        else:
+            return []
 
     # TODO tables DTO
     @property
